# MyST-NB

[![Build Status][travis-badge]][travis-link]
[![Coverage Status][coveralls-badge]][coveralls-link]
[![Documentation Status][rtd-badge]][rtd-link]
[![PyPI][pypi-badge]][pypi-link]

A collection of tools for working with Jupyter Notebooks in Sphinx.

The primary tool this package provides is a Sphinx parser for `ipynb` files.
This allows you to directly convert Jupyter Notebooks into Sphinx documents.
It relies heavily on the [`MyST` parser](https://github.com/ExecutableBookProject/myst_parser).

> 🛑🛑Warning🛑🛑
> This project is in an alpha state. It may evolve rapidly and/or make breaking changes!
> It currently depends on a fork of the Mistletoe library, so keep that in mind as you
> use it!

For more information, [see the MyST-NB documentation](https://myst-nb.readthedocs.io/en/latest/)

[travis-link]: https://travis-ci.org/ExecutableBookProject/MyST-NB
[travis-badge]: https://travis-ci.org/ExecutableBookProject/MyST-NB.svg?branch=master
[rtd-badge]: https://readthedocs.org/projects/myst-nb/badge/?version=latest
[rtd-link]: https://myst-nb.readthedocs.io/en/latest/?badge=latest
[coveralls-badge]: https://coveralls.io/repos/github/ExecutableBookProject/MyST-NB/badge.svg
[coveralls-link]: https://coveralls.io/github/ExecutableBookProject/MyST-NB
[pypi-badge]: https://img.shields.io/pypi/v/myst-nb.svg
[pypi-link]: https://pypi.org/project/myst-nb
